---
---

@import "{{ site.theme }}";

/* Additional customizations for the hacker theme */

/* Adjust content width */
.container {
  max-width: 1000px;
}

/* Improve code block readability */
code, pre {
  background-color: #101010;
  border: 1px solid #30c93b;
  border-radius: 3px;
}

pre code {
  border: none;
}

/* Improve table readability */
table {
  width: 100%;
  margin-bottom: 20px;
}

table th {
  background-color: #0d0d0d;
  border: 1px solid #30c93b;
  padding: 8px;
  text-align: left;
}

table td {
  background-color: #151515;
  border: 1px solid #30c93b;
  padding: 8px;
}

/* Enhance links */
a {
  color: #30c93b;
  text-decoration: none;
}

a:hover {
  text-decoration: underline;
  color: #b5e853;
}

/* Improve blockquote appearance */
blockquote {
  border-left: 3px solid #30c93b;
  padding-left: 10px;
  color: #b5e853;
}

/* Enhance headers */
h1, h2, h3, h4, h5, h6 {
  color: #b5e853;
}

/* Add a subtle bottom border to headers for better section separation */
h2 {
  border-bottom: 1px solid #30c93b;
  padding-bottom: 5px;
}

/* Adjust spacing */
p, ul, ol {
  margin-bottom: 15px;
} 